# pypi-auto-release
Sample auto release repository to PyPi using Github actions

Contains files for automatic deployment to PyPi using Github Actions and Github tags

Blog post explaining the implementation https://medium.com/@VersuS_/automate-pypi-releases-with-github-actions-4c5a9cfe947d

PyPi project https://pypi.org/project/pypi-auto-release/